# flake8: noqa F821

from oasysdb.collection import Collection, Record, Config


class Database:
    """The persistent storage of vector collections.

    Args:
    - path: Path to the database file.
    """

    def __init__(self, path: str,) -> None: ...

    def new(path: str) -> Database:
        """Creates a new database at the given path.
        This will reset the database if it exists.

        Args:
        - path: Path to the database file.
        """

    def get_collection(self, name: str) -> Collection:
        """Returns the collection with the given name.

        Args:
        - name: Collection name.
        """

    def save_collection(self, name: str, collection: Collection) -> None:
        """Saves new or update existing collection to the database.

        Args:
        - name: Collection name.
        - collection: Vector collection.
        """

    def delete_collection(self, name: str) -> None:
        """Deletes the collection from the database.

        Args:
        - name: Collection name.
        """

    def flush(self) -> int:
        """Flushes dirty IO buffers and calls fsync.

        Returns:
        Bytes flushed.
        """

    def async_flush(self) -> int:
        """Asynchronously performs the flush operation."""

    def len(self) -> int:
        """Returns the number of collections in the database."""

    def is_empty(self) -> bool:
        """Returns True if the database is empty."""



from oasysdb.prelude import Vector, VectorID


def test_create_vector():
    value = [0.1, 0.2, 0.3]
    vector = Vector(value)
    assert len(vector) == 3


def test_generate_random_vector():
    dimension = 128
    vector = Vector.random(dimension)
    assert len(vector) == dimension


def test_create_vector_id():
    id = 1
    vector_id = VectorID(id)
    assert vector_id.is_valid()



# flake8: noqa F403

from oasysdb.prelude import *


if __name__ == "__main__":
    # Open the database.
    db = Database("data/example")

    # Replace with your own records.
    records = Record.many_random(dimension=128, len=100)

    # Create a vector collection.
    config = Config.create_default()
    collection = Collection.from_records(config, records)

    # Optionally, persist the collection to the database.
    db.save_collection("my_collection", collection)

    # Replace with your own query.
    query = Vector.random(128)

    # Search for the nearest neighbors.
    result = collection.search(query, n=5)

    # Print the result.
    print("Nearest neighbors ID: {}".format(result[0].id))
